#
# spec file for package virtme
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%global pythons python3
%else
%global pythons python311
%endif
Name:           virtme
Version:        1.36
Release:        1.1
Summary:        Tools for virtualize the running distro or a rootfs
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/arighi/virtme-ng
Source0:        %{name}-ng-%{version}.tar.xz
BuildRequires:  %{pythons}-argcomplete
%if 0%{?suse_version} > 1600
BuildRequires:  %{pythons}-argparse-manpage
%endif
BuildRequires:  %{pythons}-requests
BuildRequires:  %{pythons}-setuptools
BuildRequires:  python-rpm-macros
Requires:       %{pythons}-argcomplete
Requires:       %{pythons}-requests
Requires:       %{pythons}-setuptools
Requires:       busybox-static
Requires:       qemu
%if 0%{?suse_version} == 1500 && 0%{?sle_version} <= 150500
Requires:       qemu-tools
%else
Requires:       virtiofsd
%endif
BuildArch:      noarch

%description
Virtme is a set of tools to run a virtualized Linux kernel that
uses the host Linux distribution or a rootfs instead of a whole
disk image.

%prep
%autosetup -n %{name}-ng-%{version} -p1

%build
%python_build
# remove pycache directories
find . -name __pycache__ -type d -exec rm -fr {} +

%install
export PYTHONDONTWRITEBYTECODE=1 %python_install
# This is a buildtime requirement, not runtime requirement
sed -i -e /argparse-manpage/d $(find %{buildroot} -name requires.txt)

%files
%{_bindir}/virtme-configkernel
%{_bindir}/virtme-ng
%{_bindir}/virtme-mkinitramfs
%{_bindir}/virtme-prep-kdir-mods
%{_bindir}/virtme-run
%{_bindir}/virtme-ssh-proxy
%{_bindir}/vng
%if 0%{?suse_version} > 1600
%{_mandir}/man1/vng.1%{?ext_man}
%endif
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}_ng
%{python_sitelib}/%{name}_ng-%{version}-py*.egg-info
%{_datadir}/bash-completion
%config(noreplace) %{_sysconfdir}/%{name}-ng.conf

%changelog
* Tue May 13 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.36:
  * vng: Fix remote build
  * virtme_ng: run: --exec and positional arguments are mutually exclusive
  * virtme-ng: run: Fix quoting
  * virtme_ng: run: Fix `vng -- ''`
* Mon May  5 2025 Fredrik Lönnegren <fredrik.lonnegren@suse.com>
- Update to 1.35:
  * Just a hotfix release to revert a change that broke some CI workflows
- Update to 1.34:
  * This new version includes lots of improvements in the SSH protocol and a
    better support for the s390 architecture.
  * Now, by default, SSH connections to the guest are using vsock, a
    lightweight transport that bypasses the full network stack and can speed up
    testing workflows.
* Thu Feb 27 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.33:
  * Restrict the SSH port to localhost (to mitigate potential security
    risks when --ssh is used)
  * Support for running amd64 vng instances on non-x86 platforms
    (e.g., running an x86 vng instance on arm64)
  * A number of minor fixes here and there.
* Tue Jan  7 2025 Fredrik Lönnegren <fredrik.lonnegren@suse.com>
- Update to 1.32:
  * numa: introduce --numa-distance
  * virtme-init: Start udev after mounting all filesystems
  * virtme: enable ssh support
  * virtme-ng: introduce --console and --ssh shortcuts
  * sshd: generate a custom sshd_config
  * virtme-ng v1.32
  * virtme-init: Enable lvm usage
  * net: support multiple interfaces
  * udhcpc: add default route if announced
  * net: allow to specify the bridge iface
  * net: option to force net MAC address
  * github: pylint: new supported versions
  * feat: vsock support for remote console access
  * vsock: connect: generate helper script
  * vsock: connect: pass command to execute
  * vsock: connect: avoid issues with modified script
  * make: build virtme-ng-init by default
  * vsock: connect: support commands without tty
  * vsock: connect: execute given cmd with right user
  * vsock: connect: only use 'su' if needed
  * vng: pass '--user root' to virtme-run
  * vsock: connect: respect '--user' if defined
  * vsock: connect: respect '--pwd' and '--cwd' if defined
  * vsock: 'socat' is required
  * vsock: rename options to --client/--server
  * console: port: switch to 2222 by default
  * console: --client and --server are mutually excl
  * console: client: support --dry-run
  * README: mention 'socat' in the requirements
  * github: restrict builds on push to the main branch
  * sshd: look for overlayfs before modifying auth keys
  * setup.py: Do not fail when argparse-manpage is not available
  * Revert "Merge pull request #184 from hramrach/main"
  * Restore bash completions
* Sat Oct 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.31:
  * Fix a packaging issue, after an attempt to modernize the build
    system we realized that we were not installing the bash
    completion file anymore, so we have temporarily reverted the
    change to cut this new release.
    See gh/arighi/virtme-ng#181
  * Initial support to run virtme-ng on macOS
* Tue Oct 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.30:
  * Initial support for NVIDIA GPUs passthrough
  * Possibility to use pre-compiled -rc kernels from Ubuntu mainline builds
  * Possibility to use virtiofs natively on arm64
  * Some improvements to run virtme-ng cross-architecture and cross-distro
  * Bug fixes
* Tue Sep 17 2024 Michal Suchanek <msuchanek@suse.com>
- Workaround python packaging deficiency
* Wed Sep 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.29:
  * Minor packaging fix, addressing an issue where the requirements.txt
    file was missing from the source tarball published on PyPI.
    This won't affect anyone, unless you're trying to build virtme-ng
    directly from the tarball available on PyPI
* Fri Sep  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.28:
  * setup.py: include dependencies parsing requirements.txt
  * virtme-ng: fix typo in command help
  * virtme-configkernel: disable nvram support
  * configkernel: config comment cosmetics
  * configkernel: act more like kernel's make O=outdir
  * vng-run: get kdir from O=outdir
  * vng: propagate --verbose to configkernel
  * vng: alias --custom to --config
  * run.py: add a --qemu-opts='...' option bundling hint to help
  * init: Always create /run/tmp folder
  * Don't require ".git" to be a directory
  * Specify "refs/heads/__virtme__" in git push
- Add BuildRequires for python-argparse-manpage and install man
  page if we are on TW. Older versions don't have the dep yet
* Wed Jul 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.27:
  * Introduce VNG_PACKAGE to force a proper packaging version
    virtme-ng v1.27
* Tue Jul 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.26:
  * Proper integration with Arch
  * Inclusion of a vng manpage
  * The host's /tmp is now also visible from the guest
  * A new --configitem option that allows to quickly change specific
    kernel config options (with --build)
  * Bug fixes
- Remove 0001-virtme-ng-fix-virtiofsd-search-path-on-openSUSE.patch
* Mon Jun 10 2024 Johannes Thumshirn <jth@kernel.org>
- Fix virtiofsd search path
  + 0001-virtme-ng-fix-virtiofsd-search-path-on-openSUSE.patch
* Wed May 22 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.25:
  * significantly improve boot time with the microvm architecture
    (simply by enabling the RTC and avoiding unnecessary boot time
    that most kernels spend probing for a non-existent RTC)
  * virtme: make sure RTC is enabled with microvm
  * virtme-ng: silent lint errors
  * github: new test with KVM support
* Fri May  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.24:
  * The most noticeable changes include the support for the loop
    network type and the possibility to specify the --network
    command multipe times, both useful for kernel selftests testing
  * Moreover, there is a boot-time improvement in environments where
    the kvm acceleration is not available, such as container, cloud
    environments, etc. (using the q35 arch in qemu).
  * Notably, this new version is expected to enhance the performance
    of GitHub workflows that use virtme-ng.
* Fri Mar 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.23:
  * Fix breakage with QEMU 8.2.2
  * Change behaviour of --kconfig, that will always override
    the .config if present (since there is not reason to use
  - -kconfig and not update the .config).
  * It is now possible to force the legacy cgroup v1 using the
    option -a "SYSTEMD_CGROUP_ENABLE_LEGACY_FORCE=1": the vng
    init script will mimic systemd behavior and mount cgroup v1,
    instead of v2.
- Drop qemu-remove-unnecessary-serial-none-arg.patch
* Thu Mar 28 2024 Michal Suchanek <msuchanek@suse.com>
- qemu 8.2.2 compatibility
  * qemu-remove-unnecessary-serial-none-arg.patch
* Mon Mar  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.22:
  * Fix potential sudo errors (in openSUSE, Fedora, CachyOS)
  * Propagate /proc/sys/fs/nr_open from host to guest
  * More robust parsing of upstream kernel versions
  * Small command help improvements
- Update to 1.21:
  * When running in script mode do not hang in case of kernel panic,
    but return the special error code 255 (this allows to automate
    catching kernel panics)
  * Redirect kernel log to stderr on the host when running in interactive
    mode: this allows to easily save the kernel log to a file (or pipe
    it to another tool), simply by runing a vng -vr 2>/tmp/kernel.log
  * vng --dump can now generate a memory dump compatible with drgn
  * It is now possible to use virtiofsd with a btrfs root filesystem
    on the host (e.g., default openSUSE setup)
  * It is not possible to to use the microvm architecture with kernels
    that don't have built-in virtio-pci / virtio-mmio (e.g., stock
    openSUSE Tumbleweed kernel)
- Update to 1.20:
  * The return code of a command executed in the vng guest is now
    transparently channeled to the host: this, together with
    stdin/stdout/stderr redirection, gives the complete illusion to
    run the command in the guest as if it was executed on the host
    and it can help to easily integrate vng with other CI tools/scripts
  * NUMA support: it is now possible to create multiple NUMA nodes,
    and assign CPUs to them, inside a vng guest,
    using the --numa option.
  * new --quiet option to override --verbose
  * new --disable-kvm option to explicitly disable hardware
    virtualization (KVM)
  * lockdep is now disabled by default during the kernel build
- Update to 1.19:
  * The most noticeable change is definitely the support for running
    virtme-ng inside Docker containers. This opens the possibility for
    many other projects to use virtme-ng to potentially pick any
    arbitrary kernel to run their tests inside their Docker instances.
  * The other interesting change (this one only for Ubuntu users) is
    the --root-release argument (used together with --root) that allows
    bootstrapping a rootfs from scratch, selecting a specific Ubuntu
    release. The rootfs will be created from the latest Ubuntu cloud
    image of the target release.
- Add dependency on `requests`
- Add _service file:
  They use git submodule to get virtme_ng_init.
* Fri Feb 23 2024 Marcos de Souza <mpdesouza@suse.com>
- Fix python version checking
* Thu Feb 22 2024 Marcos de Souza <mpdesouza@suse.com>
- Requires setuptools and argcomplete, instead of just require it for building
* Wed Dec 13 2023 Robert Frohl <rfrohl@suse.com>
- Require qemu-tools instead virtiofsd for older SLE/Leap versions
* Thu Nov 30 2023 Michal Suchanek <msuchanek@suse.com>
- Update to version 1.18
  * restore old --run behavior
  * fix --user behavior
* Thu Nov 16 2023 Takashi Iwai <tiwai@suse.com>
- virtme-ng version: 1.17
  * Fixes Leap build
* Fri Apr 21 2023 Michal Suchanek <msuchanek@suse.com>
- Update project URL: https://github.com/arighi/virtme
- Update to version 0.1.2
  - Remove upstreamed patches
  - 0001-Add-save-initramfs-to-save-the-actual-generated-init.patch
  - 0002-Make-save-initramfs-show-command-output-more-useful.patch
  - 0003-Fix-the-error-message-for-mods-misuse.patch
  - 0004-Fix-the-mods-error-even-better.patch
  - 0005-mkinitramfs.py-Search-for-busybox-.-static-first.patch
  - 0006-mkinitramfs-Improve-the-find_busybox-algorithm.patch
  - 0007-Add-util.find_binary-to-find-binaries.patch
  - 0008-modfinder-Use-find_binary_or_raise-to-find-modprobe.patch
  - 0009-Enable-the-Xen-console-when-using-xen.patch
  - 0001-configkernel-Add-CONFIG_INOTIFY_USER-y.patch
  - 0002-Use-fsdev-multidevs-remap-on-QEMU-4.2.patch
  - 0003-Add-more-typing-annotations.patch
  - 0004-run.py-Extract-path-file-sanitizing-into-a-new-funct.patch
  - 0005-run.py-Introduce-blk-disk-argument.patch
  - 0006-Minor-sanitize_disk_args-cleanup.patch
  - aarch64-Fix-aarch64-support.patch
* Tue Dec 14 2021 ohering@suse.de
- Add python-rpm-macros (bsc#1180125)
* Thu Nov 12 2020 Matthias Brugger <mbrugger@suse.com>
- Update patch for aarch64 support. Does not break full emulation case.
* Fri Oct 30 2020 Matthias Brugger <mbrugger@suse.com>
- Add patch to fix aarch64 native support.
  * aarch64-Fix-aarch64-support.patch
* Wed Jul 22 2020 Marcos de Souza <mpdesouza@suse.com>
- Add patches to include some fixes and the new --blk-disk feature
  * 0001-Add-save-initramfs-to-save-the-actual-generated-init.patch
  * 0002-Make-save-initramfs-show-command-output-more-useful.patch
  * 0003-Fix-the-error-message-for-mods-misuse.patch
  * 0004-Fix-the-mods-error-even-better.patch
  * 0005-mkinitramfs.py-Search-for-busybox-.-static-first.patch
  * 0006-mkinitramfs-Improve-the-find_busybox-algorithm.patch
  * 0007-Add-util.find_binary-to-find-binaries.patch
  * 0008-modfinder-Use-find_binary_or_raise-to-find-modprobe.patch
  * 0009-Enable-the-Xen-console-when-using-xen.patch
  * 0001-configkernel-Add-CONFIG_INOTIFY_USER-y.patch
  * 0002-Use-fsdev-multidevs-remap-on-QEMU-4.2.patch
  * 0003-Add-more-typing-annotations.patch
  * 0004-run.py-Extract-path-file-sanitizing-into-a-new-funct.patch
  * 0005-run.py-Introduce-blk-disk-argument.patch
  * 0006-Minor-sanitize_disk_args-cleanup.patch
- Drop outdated patch:
  * 0001-mkinitramfs.py-Search-for-busybox-.-static-first.patch
* Thu Oct 17 2019 Marcos de Souza <mpdesouza@suse.com>
- Current Tumbleweed's busybox does not work with virtme. For now require
  busybox-static since it works;
  * 0001-mkinitramfs.py-Search-for-busybox-.-static-first.patch: Check for
    busybox-static over dynamically linked busybox
- Change the dependency to busybox-static instead of the dynamically linked on.
* Wed Oct 16 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias, conjecture and vision from descriptions.
- Use noun phrase in summary.
* Tue Oct 15 2019 Marcos de Souza <mpdesouza@suse.com>
- Remove the python3- prefix from the final package
- Added full source URL
* Tue Oct 15 2019 Marcos de Souza <mpdesouza@suse.com>
- Remove _service and add the virtme source code into the project.
* Sat Oct 12 2019 Marcos de Souza <mpdesouza@suse.com>
- Add busybox and qemu as dependencies of virtme. Now 'virtme-run
  - -installed-kernel' works out-of-the-box.
* Thu Oct 10 2019 Marcos de Souza <mpdesouza@suse.com>
- Newly released version 0.1.1
- Use an OBS service to download the tarball
- Removed all patches, since they are all included in the new version
* Mon Sep 30 2019 Marcos de Souza <mpdesouza@suse.com>
- Add a new patch to support --mods auto in openSUSE.
* Mon Sep 30 2019 Marcos de Souza <mpdesouza@suse.com>
- Update virtme version with previous patches already included in the upstream
  project
* Mon Aug 26 2019 Marcos de Souza <mpdesouza@suse.com>
- Add patches to enable experimental --kdir with modules enabled
* Thu Aug 22 2019 Marcos de Souza <mpdesouza@suse.com>
- First version of the package
